==> bw-xml-synchws-4.0.7-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/StringPropertyType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *            Base type for string properties returned in GetPropertiesResponse. 
 *       
 * 
 * <p>Java class for StringPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StringPropertyType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://docs.oasis-open.org/ws-calendar/ns/soap}GetPropertiesBasePropertyType">
 *       &lt;sequence>
 *         &lt;element name="string" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StringPropertyType", propOrder = {
    "string"
})
@XmlSeeAlso({
    ResourceTimezoneIdType.class,
    XresourceType.class,
    DisplayNameType.class,
    ResourceOwnerType.class,
    TimezoneServerType.class,
    PrincipalHomeType.class,
    ResourceDescriptionType.class
})
public class StringPropertyType
    extends GetPropertiesBasePropertyType
{

    @XmlElement(required = true)
    protected String string;

    /**
     * Gets the value of the string property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getString() {
        return string;
    }

    /**
     * Sets the value of the string property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setString(String value) {
        this.string = value;
    }

}

==> bw-xml-synchws-5.0.0-sources.jar: org/oasis_open/docs/ws_calendar/ns/soap/StringPropertyType.java <==

package org.oasis_open.docs.ws_calendar.ns.soap;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * 
 *            Base type for string properties returned in GetPropertiesResponse. 
 *       
 * 
 * <p>Java class for StringPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="StringPropertyType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://docs.oasis-open.org/ws-calendar/ns/soap}GetPropertiesBasePropertyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="string" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "StringPropertyType", propOrder = {
    "string"
})
@XmlSeeAlso({
    DisplayNameType.class,
    PrincipalHomeType.class,
    ResourceDescriptionType.class,
    ResourceOwnerType.class,
    XresourceType.class,
    ResourceTimezoneIdType.class,
    TimezoneServerType.class
})
public class StringPropertyType
    extends GetPropertiesBasePropertyType
{

    @XmlElement(required = true)
    protected String string;

    /**
     * Gets the value of the string property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getString() {
        return string;
    }

    /**
     * Sets the value of the string property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setString(String value) {
        this.string = value;
    }

}
